@@ -6,6 +6,7 @@ Borrows heavily from pathlib, os, shutil, and glob
 
 import os as _os
 import sys as _sys
+import site as _site
 import importlib.util
 import shutil as _shutil
 import inspect as _inspect
@@ -20,7 +21,10 @@ filedir = None
 
 for frame in _inspect.stack()[1:]:
     if frame.filename[0] != "<":
-        filedir = _os.path.split(frame.filename)[0]
+        if _os.path.isfile(frame.filename):
+            filedir = _os.path.dirname(frame.filename)
+        else:
+            filedir = frame.filename
         break
 if filedir == None:
     # Returns cwd for interactive terminals
@@ -43,7 +47,7 @@ class Path(str):
         if custom:
             paths = []
         else:
-            paths = [_os.path.dirname(filedir)]
+            paths = [filedir]
 
         for arguments in args:
             if arguments == "..":
@@ -212,7 +216,7 @@ class Path(str):
     def readfast(self, *args, **kwargs) -> Any:
         """
         good for reading the first few of lines of a VERY LARGE file
-        
+
         returns generator for reading large files one line at a time
 
         file_text = Path.readfast()
@@ -246,14 +250,14 @@ class Path(str):
         """
         path = _os.path.split(self.string())
         if full == True:
-            return self.__str__().split(os.path.sep)
+            return self.__str__().split(_os.path.sep)
         else:
             return [Path(path[0], custom=True), path[1]]
 
     def branch(self) -> str:
         """
         /absolute/path/to/leaf -> returns branch
-        
+
         print(Path.branch()) # /absolute/path/to
         """
         return self.splitpath()[0]
@@ -261,7 +265,7 @@ class Path(str):
     def leaf(self) -> str:
         """
         /absolute/path/to/leaf -> returns leaf
-        
+
         print(Path.leaf()) # leaf
         """
         return self.splitpath()[1]
@@ -283,7 +287,7 @@ def importfile(path: str, module: Optional[Any] = None) -> Any:
         path: str or str-like object with path to directory
         module: module that will have attributes appended to it
 
-    returns file functions, classes, and global variables from a python file
+    Returns file functions, classes, and global variables from a python file
     """
     path = Path(path, custom=True)
     assert _os.path.isfile(path) == True
@@ -311,9 +315,9 @@ class importdir:
         path: str or str-like object with path to directory
         module: module that will have attributes appended to it
 
-    imports *.py files from directory
+    Imports *.py files from directory
 
-    returns class with attributes named after *.py files
+    Returns class with attributes named after *.py files
     """
 
     def __init__(self, path: str, module: Optional[Any] = None) -> Union[Any, None]:
@@ -338,3 +342,123 @@ class importdir:
 
 cwd = Path(str(_Path.cwd()), custom=True)
 filedir = Path(filedir, custom=True)
+
+# keep old import statement for future reference
+old_import = __import__
+modules = _sys.modules
+
+# find out where site-packages are
+site_packages = [url for url in _sys.path if "site-packages" in url]
+packages = []
+
+# keep a set of module names
+for url in site_packages:
+    url = Path(url, custom=True)
+    names = url.ls()
+    for name in names:
+        if name[-3:] == ".py":
+            name = name[:-3]
+        packages.append(name)
+
+packages = set(packages)
+
+# sometimes a module is imported that is not in site-packages
+# however, these urls usually use the same first two folders
+# this might break in the future, needs a better implementation
+first_two_folders = _site.getsitepackages()[0].split(_os.path.sep)[:3]
+packages_root = _os.path.sep.join(first_two_folders)
+
+
+def evaluate_name(name: str, url: str, up_dir: int = 1) -> Any:
+    """
+    evaluate_name(name, url, up_dir=1)
+
+    Parameters:
+        name:
+        url:
+        up_dir: how many times
+
+    Returns either an importdir or importfile, depending on the url given
+
+    If url can be either a file or a directory, raises ImportError
+    If url is not found, will raise an ImportError
+    """
+    up_dir -= 1
+    up_dir = [".." for i in range(up_dir)]
+
+    url = Path(url, custom=True)
+    directory = url.branch()
+    name = name.split(".")
+
+    final = directory.add(*up_dir, *name)
+
+    is_file = _os.path.isfile(final + ".py")
+    is_dir = _os.path.isdir(final)
+
+    if is_file and is_dir:
+        print(f"Ambiguous reference, file and directory found for {name} at {final}")
+        raise ImportError
+    elif is_file:
+        return importfile(final + ".py")
+    elif is_dir:
+        return importdir(final)
+    else:
+        print(f"Relative importing was not able to find package at {final}")
+        raise ImportError()
+
+
+def new_import(*args, **kwargs):
+    """
+    Replaces the builtins.__import__ statment, this allows for normal import syntax but with relative imports
+
+    Caveats:
+        - runs __init__.py if folder is imported
+        - runs __init__.py if file is in the same folder as __init__.py
+        - only the "from _ import _" statement is overidden
+        - only *.py files are imported
+        - directories are not recursively added
+        - if directories are added in the __init__.py file, directories are added to namespace
+
+    Dot notation:
+        - go up n-1 folders, with n representing the number of dots
+    """
+    file = args[1]["__name__"]
+    name = args[0]
+    package_name = args[1]["__name__"]
+
+    try:
+        # normal files
+        url = args[1]["__file__"]
+    except:
+        # make fake url for virtual environments
+        url = filedir / "virtual_environment"
+
+    if "." in name:
+        if name[0] == ".":
+            # this should not happen
+            # putting this here in case python changes
+            # interpreter behavior in the future
+            print(". found at beginning")
+        else:
+            name = name.split(".")[0]
+
+    # it's in the packages
+    if packages_root in url:
+        imported = old_import(*args, **kwargs)
+    elif name in packages and args[4] == 0:
+        imported = old_import(*args, **kwargs)
+    elif name in modules and args[4] == 0:
+        imported = old_import(*args, **kwargs)
+
+    # not in the package but goes up folders
+    elif args[4] != 0:
+        imported = evaluate_name(args[0], url, args[4])
+    # did not expect this to be run; here just in case
+    elif "." in args[0]:
+        imported = evaluate_name(name, url)
+
+    # just in case
+    else:
+        imported = old_import(*args, **kwargs)
+
+    return imported
